==> HostCMS-6.1.7.tar: HostCMS.pl <==
#!/usr/local/bin/perl -w
########################
# $ZenonID$
########################

use strict;

my $insdir = $ARGV[0] if defined $ARGV[0]; # Installation directory
my $srvhst = $ARGV[1] if defined $ARGV[1]; # www.domain.com
my $dbhost = $ARGV[2] if defined $ARGV[2]; # DBHOST
my $dbport = $ARGV[3] if defined $ARGV[3]; # DBPORT
my $dbuser = $ARGV[4] if defined $ARGV[4]; # DBUSER
my $dbname = $ARGV[5] if defined $ARGV[5]; # DBNAME
my $dbpass = $ARGV[6] if defined $ARGV[6]; # DBPASS
my $mail  =  $ARGV[7] if defined $ARGV[7]; # Admin EMAIL
my $hmdir = $ENV{'HOME'};
my $sa;

my ($pid) = $$;

system("echo $pid > $hmdir/softinstall_$srvhst\_pid");

sleep(1);

close(STDERR);
close(STDOUT);

open(LOG,"> $ENV{'HOME'}/softinstall.log");
*STDERR = *LOG;
*STDOUT = *LOG;

open(N, ">> /dev/null");
*STDIN = *N;

# Next 2 variables must be set correctly! Depends on current soft package!
my $instpg = "admin/index.php";
my $inspkg = "HostCMS";
my $path = "/bhome/softpackages/free";
my $message = "";
my $lnk = SetLink();
chomp($lnk);

# ------------
  $message = "$message <div> !<br>          \"admin\"   \"123456\",         .     , ,    $lnk.</div>";
# ------------

if (!($insdir) || !($srvhst) || !($dbhost) || !($dbport) || !($dbuser) || !($dbname) || !($dbpass) || !($mail)) {
  print "<font color=\"red\"></font>:  !\n"; exit 0 
} else {
 my $err = SoftInstall();
 if ($err == 0) {
  print "$message\n";
  exit 0;
 } else {
   print "<font color=\"red\"></font>. ,       support\@zenon.net!\n";
 }
}

sub SetLink {
  $insdir =~ m/www\//g;
  my $path = substr($insdir, pos($insdir));
  chomp($path);
  if ($path) { $path = "$path/" }
  my $inslnk = "<a href=\"http://$srvhst/$path$instpg\" target=\"blank\">$inspkg</a>";
  chomp($inslnk);
  return $inslnk;
}

sub SoftInstall {
  dbinstall(); 					# Here must be installation instructions
  PrepareDir($insdir);
  system("/usr/bin/tar -C $insdir -zxvf $path/$inspkg/$inspkg.tar");
 # --------------------
  rename("$insdir/modules/core/config/database.php", "$insdir/modules/core/config/database.php.old");
  system("/usr/bin/touch $insdir/modules/core/config/database.php");
  open (FN, ">$insdir/modules/core/config/database.php");
  open (FO, "$insdir/modules/core/config/database.php.old");
  while (<FO>) {
    chomp($_);
    $_ =~ s/\[dbhost.port\]/$dbhost:$dbport/g ;
    $_ =~ s/\[dbuser\]/$dbuser/g ;
    $_ =~ s/\[dbpassword\]/$dbpass/g ;
    $_ =~ s/\[dbname\]/$dbname/g ;
    print (FN "$_\n");
  }
  close FO;
  close FN;
   unlink("$insdir/modules/core/config/database.php.old");
 # --------------------
   unlink("$hmdir/softinstall_$srvhst\_pid");
  return 0; 						# In case of "OK"
}

sub dbinstall {
  my $newhost= $srvhst; 
  $newhost =~ s/www\.//g;
  my $mysqlstr="/usr/local/bin/mysql -h$dbhost -P$dbport -u$dbuser -p$dbpass $dbname";
  system("/usr/local/bin/mysqladmin -h$dbhost -P$dbport -u$dbuser -p$dbpass create $dbname");
  system("$mysqlstr < $path/$inspkg/$inspkg.db");
  system("$mysqlstr -e 'UPDATE users SET email=\"$mail\" where login=\"admin\"'");
  system("$mysqlstr -e 'TRUNCATE TABLE site_aliases'");
  system("$mysqlstr -e 'INSERT INTO site_aliases VALUES (1,1,\"*.$newhost\",1,0,0)'");
  return 0;
}

sub PrepareDir {
  my ($dir) = @_;
  my @list = split(/\//,$dir);
  my $li;
  my $path = "";
  foreach $li (@list) {
  next if ($li eq "");
  $path = "$path/$li";
    if (!(-d $path)) {
     chomp($li);
     system("/bin/mkdir $path");
    } else {
     next ; 
    }
  }
}

==> HostCMS-6.8.6.tar: HostCMS.pl <==
#!/usr/local/bin/perl -w
########################
# $ZenonID$
########################

use strict;

my $insdir = $ARGV[0] if defined $ARGV[0]; # Installation directory
my $srvhst = $ARGV[1] if defined $ARGV[1]; # www.domain.com
my $dbhost = $ARGV[2] if defined $ARGV[2]; # DBHOST
my $dbport = $ARGV[3] if defined $ARGV[3]; # DBPORT
my $dbuser = $ARGV[4] if defined $ARGV[4]; # DBUSER
my $dbname = $ARGV[5] if defined $ARGV[5]; # DBNAME
my $dbpass = $ARGV[6] if defined $ARGV[6]; # DBPASS
my $mail  =  $ARGV[7] if defined $ARGV[7]; # Admin EMAIL
my $hmdir = $ENV{'HOME'};
my $sa;

my ($pid) = $$;

system("echo $pid > $hmdir/softinstall_$srvhst\_pid");

sleep(1);

close(STDERR);
close(STDOUT);

open(LOG,"> $ENV{'HOME'}/softinstall.log");
*STDERR = *LOG;
*STDOUT = *LOG;

open(N, ">> /dev/null");
*STDIN = *N;

# Next 2 variables must be set correctly! Depends on current soft package!
my $instpg = "admin/index.php";
my $inspkg = "HostCMS";
my $path = "/bhome/softpackages/free";
my $message = "";
my $lnk = SetLink();
chomp($lnk);

# ------------
  $message = "$message <div> !<br>          \"admin\"   \"admin\",         .     , ,    $lnk.</div>";
# ------------

if (!($insdir) || !($srvhst) || !($dbhost) || !($dbport) || !($dbuser) || !($dbname) || !($dbpass) || !($mail)) {
  print "<font color=\"red\"></font>:  !\n"; exit 0 
} else {
 my $err = SoftInstall();
 if ($err == 0) {
  print "$message\n";
  exit 0;
 } else {
   print "<font color=\"red\"></font>. ,       support\@zenon.net!\n";
 }
}

sub SetLink {
  $insdir =~ m/www\//g;
  my $path = substr($insdir, pos($insdir));
  chomp($path);
  if ($path) { $path = "$path/" }
  my $inslnk = "<a href=\"http://$srvhst/$path$instpg\" target=\"blank\">$inspkg</a>";
  chomp($inslnk);
  return $inslnk;
}

sub SoftInstall {
  dbinstall(); 					# Here must be installation instructions
  PrepareDir($insdir);
  system("/usr/bin/tar -C $insdir -zxvf $path/$inspkg/$inspkg.tar");
 # --------------------
  rename("$insdir/modules/core/config/database.php", "$insdir/modules/core/config/database.php.old");
  system("/usr/bin/touch $insdir/modules/core/config/database.php");
  open (FN, ">$insdir/modules/core/config/database.php");
  open (FO, "$insdir/modules/core/config/database.php.old");
  while (<FO>) {
    chomp($_);
    $_ =~ s/\[dbhost.port\]/$dbhost:$dbport/g ;
    $_ =~ s/\[dbuser\]/$dbuser/g ;
    $_ =~ s/\[dbpassword\]/$dbpass/g ;
    $_ =~ s/\[dbname\]/$dbname/g ;
    print (FN "$_\n");
  }
  close FO;
  close FN;
   unlink("$insdir/modules/core/config/database.php.old");
 # --------------------
   unlink("$hmdir/softinstall_$srvhst\_pid");
  return 0; 						# In case of "OK"
}

sub dbinstall {
  my $newhost= $srvhst; 
  $newhost =~ s/www\.//g;
  my $mysqlstr="/usr/local/bin/mysql -h$dbhost -P$dbport -u$dbuser -p$dbpass $dbname";
  system("/usr/local/bin/mysqladmin -h$dbhost -P$dbport -u$dbuser -p$dbpass create $dbname");
  system("$mysqlstr < $path/$inspkg/$inspkg.db");
  system("$mysqlstr -e \"UPDATE sites SET admin_email='$mail' where id=1\"");
  system("$mysqlstr -e \"TRUNCATE TABLE site_aliases\"");
  system("$mysqlstr -e \"INSERT INTO site_aliases VALUES (1,1,'*.$newhost',0,0,19,0)\"");
  system("$mysqlstr -e \"UPDATE directory_emails SET `value` = '$mail' WHERE id=5\"");
  return 0;
}

sub PrepareDir {
  my ($dir) = @_;
  my @list = split(/\//,$dir);
  my $li;
  my $path = "";
  foreach $li (@list) {
  next if ($li eq "");
  $path = "$path/$li";
    if (!(-d $path)) {
     chomp($li);
     system("/bin/mkdir $path");
    } else {
     next ; 
    }
  }
}
